==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapResourceEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapResourceEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getId();
        }
    },
    ATTRIBUTES {
        public static final String FIELD_NAME = "Attributes";
        public static final String FIELD_NAME_DASHED = "attributes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return java.util.List.class;
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authorization.entity.MapResourceEntity e, K key, T value) {
            e.setAttribute((String) key, (java.util.List<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (java.util.Map<String,java.util.List<String>>) e.getAttributes();
        }
        @SuppressWarnings("unchecked") @Override public <K> java.util.List<String> mapGet(org.keycloak.models.map.authorization.entity.MapResourceEntity e, K key) {
            return (java.util.List<String>) e.getAttribute((String) key);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authorization.entity.MapResourceEntity e, K p0) {
            e.removeAttribute((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setAttributes((java.util.Map<String,java.util.List<String>>) value);
        }
    },
    DISPLAY_NAME {
        public static final String FIELD_NAME = "DisplayName";
        public static final String FIELD_NAME_DASHED = "display-name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getDisplayName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setDisplayName((String) value);
        }
    },
    ICON_URI {
        public static final String FIELD_NAME = "IconUri";
        public static final String FIELD_NAME_DASHED = "icon-uri";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setIconUri((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getIconUri();
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setName((String) value);
        }
    },
    OWNER {
        public static final String FIELD_NAME = "Owner";
        public static final String FIELD_NAME_DASHED = "owner";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getOwner();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setOwner((String) value);
        }
    },
    OWNER_MANAGED_ACCESS {
        public static final String FIELD_NAME = "OwnerManagedAccess";
        public static final String FIELD_NAME_DASHED = "owner-managed-access";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setOwnerManagedAccess((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (Boolean) e.isOwnerManagedAccess();
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setResourceServerId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getResourceServerId();
        }
    },
    SCOPE_IDS {
        public static final String FIELD_NAME = "ScopeIds";
        public static final String FIELD_NAME_DASHED = "scope-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setScopeIds((java.util.Set<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (java.util.Set<String>) e.getScopeIds();
        }
    },
    TYPE {
        public static final String FIELD_NAME = "Type";
        public static final String FIELD_NAME_DASHED = "type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setType((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getType();
        }
    },
    URIS {
        public static final String FIELD_NAME = "Uris";
        public static final String FIELD_NAME_DASHED = "uris";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (java.util.Set<String>) e.getUris();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setUris((java.util.Set<String>) value);
        }
    },
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceEntityFields.java <==
package org.keycloak.models.map.authorization.entity;
public enum MapResourceEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.authorization.entity.MapResourceEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setId((String) value);
        }
    },
    ATTRIBUTES {
        public static final String FIELD_NAME = "Attributes";
        public static final String FIELD_NAME_DASHED = "attributes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return java.util.List.class;
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.authorization.entity.MapResourceEntity e, K key, T value) {
            e.setAttribute((String) key, (java.util.List<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.authorization.entity.MapResourceEntity e, K p0) {
            e.removeAttribute((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (java.util.Map<String,java.util.List<String>>) e.getAttributes();
        }
        @SuppressWarnings("unchecked") @Override public <K> java.util.List<String> mapGet(org.keycloak.models.map.authorization.entity.MapResourceEntity e, K key) {
            return (java.util.List<String>) e.getAttribute((String) key);
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setAttributes((java.util.Map<String,java.util.List<String>>) value);
        }
    },
    DISPLAY_NAME {
        public static final String FIELD_NAME = "DisplayName";
        public static final String FIELD_NAME_DASHED = "display-name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getDisplayName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setDisplayName((String) value);
        }
    },
    ICON_URI {
        public static final String FIELD_NAME = "IconUri";
        public static final String FIELD_NAME_DASHED = "icon-uri";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setIconUri((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getIconUri();
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getName();
        }
    },
    OWNER {
        public static final String FIELD_NAME = "Owner";
        public static final String FIELD_NAME_DASHED = "owner";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getOwner();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setOwner((String) value);
        }
    },
    OWNER_MANAGED_ACCESS {
        public static final String FIELD_NAME = "OwnerManagedAccess";
        public static final String FIELD_NAME_DASHED = "owner-managed-access";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (Boolean) e.isOwnerManagedAccess();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setOwnerManagedAccess((Boolean) value);
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setRealmId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getRealmId();
        }
    },
    RESOURCE_SERVER_ID {
        public static final String FIELD_NAME = "ResourceServerId";
        public static final String FIELD_NAME_DASHED = "resource-server-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getResourceServerId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setResourceServerId((String) value);
        }
    },
    SCOPE_IDS {
        public static final String FIELD_NAME = "ScopeIds";
        public static final String FIELD_NAME_DASHED = "scope-ids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setScopeIds((java.util.Set<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (java.util.Set<String>) e.getScopeIds();
        }
    },
    TYPE {
        public static final String FIELD_NAME = "Type";
        public static final String FIELD_NAME_DASHED = "type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (String) e.getType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setType((String) value);
        }
    },
    URIS {
        public static final String FIELD_NAME = "Uris";
        public static final String FIELD_NAME_DASHED = "uris";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.authorization.entity.MapResourceEntity e, T value) {
            e.setUris((java.util.Set<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.authorization.entity.MapResourceEntity e) {
            return (java.util.Set<String>) e.getUris();
        }
    },
}
